# -*- coding: utf-8 -*-
# <Lettuce - Behaviour Driven Development for python>
# Copyright (C) <2010>  Gabriel Falcão <gabriel@nacaolivre.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

LANGUAGES = {
    'en': {
        'examples': u'Examples|Scenarios',
        'feature': u'Feature',
        'name': u'English',
        'native': u'English',
        'scenario': u'Scenario',
        'scenario_outline': u'Scenario Outline',
        'scenario_separator': u'(Scenario Outline|Scenario)',
    },
    'pt-br': {
        'examples': u'Exemplos|Cenários',
        'feature': u'Funcionalidade',
        'name': u'Portuguese',
        'native': u'Português',
        'scenario': u'Cenário|Cenario',
        'scenario_outline': u'Esquema do Cenário|Esquema do Cenario',
        'scenario_separator': u'(Esquema do Cenário|Esquema do Cenario|Cenario|Cenário)',
    },
    'pl': {
        'examples': u'Przykład',
        'feature': u'Właściwość',
        'name': u'Polish',
        'native': u'Polski',
        'scenario': u'Scenariusz',
        'scenario_outline': u'Zarys Scenariusza',
        'scenario_separator': u'(Zarys Scenariusza|Scenariusz)',
    },
}
